/**
 * @file micronode_block.js
 */

(function ($, Drupal, drupalSettings) {

  // Certain customizations related to the modal form were not
  // going wel in php. So we resort to javascript to modify buttons
  // in the entity browser modal form for the micronode_block block.
  // We also use this to customize the title of the dialog.
  Drupal.behaviors.micronodeBlock = {
    attach: function (context) {
      // Hide the "Add Microcontent" button if microcontent has been selected already.
      $('[data-drupal-selector="edit-settings-selection-entity-browser-entity-browser"]', context).each(function(){
        var $form = $(this).closest('form');
        if (!$form.hasClass('micronode-block-form')) {
          return;
        }
        $input = $form.find('.eb-target');
        if ($input.length && $input.val()) {
          $(this).addClass('hidden');
        }
        else {
          $(this).removeClass('hidden');
          // Give a better label.
          if (drupalSettings.micronode_block && drupalSettings.micronode_block.bundle_label) {
            $(this).find('[type="submit"]').val('Add ' + drupalSettings.micronode_block.bundle_label);
          }
          // Trigger the modal to open.
          $(this).find('[type="submit"]').addClass('button--primary').click();
        }
      });
      // Disable the Save button if no microcontent is selected.
      $('[data-drupal-selector="edit-actions-submit"]', context).each(function(){
        var $form = $(this).closest('form');
        if (!$form.hasClass('micronode-block-form')) {
          return;
        }
        $input = $form.find('.eb-target');
        if ($input.length && $input.val()) {
          $(this).prop('disabled', false);
        }
        else {
          $(this).prop('disabled', 'disabled');
        }
      });
      $(once('micronode_block_rewrite_modal_title', '.entity-browser-modal .ui-dialog-title')).each(function(){
        if (drupalSettings.micronode_block && drupalSettings.micronode_block.bundle_label) {
          $(this).text('Add ' + drupalSettings.micronode_block.bundle_label);
        }
      });
    }
  };

}(jQuery, Drupal, drupalSettings));
