<?php

namespace Drupal\micronode_block\Plugin\Derivative;

use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Retrieves block plugin definitions for all micronode types that are
 * classified by type_tray as "component".
 */
class MicronodeBlockDeriver extends DeriverBase implements ContainerDeriverInterface {

  /**
   * The node type storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $nodeTypeStorage;

  /**
   * {@inheritdoc}
   */
  public function __construct(EntityStorageInterface $node_type_storage) {
    $this->nodeTypeStorage = $node_type_storage;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    $entity_manager = $container->get('entity_type.manager');
    return new static(
      $entity_manager->getStorage('node_type')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    $node_types = $this->nodeTypeStorage->loadMultiple();
    // Reset the discovered definitions.
    $this->derivatives = [];
    foreach ($node_types as $node_type) {
      if (
        !empty($node_type->get('third_party_settings')['micronode']['micronode_is_microcontent'])
        //&& $node_type->get('third_party_settings')['type_tray']['type_category'] === 'component'
      ) {
        $this->derivatives[$node_type->id()] = $base_plugin_definition;
        $this->derivatives[$node_type->id()]['admin_label'] = $node_type->label();
        $this->derivatives[$node_type->id()]['config_dependencies']['config'] = [
          $node_type->getConfigDependencyName(),
        ];
      }
    }
    return parent::getDerivativeDefinitions($base_plugin_definition);
  }

}
