<?php

namespace Drupal\micronode_block\Plugin\EntityBrowser\WidgetSelector;

use Drupal\entity_browser\Plugin\EntityBrowser\WidgetSelector\Tabs;
use Drupal\Core\Form\FormStateInterface;

/**
 * Fixes labels on tabs.
 *
 * If we use the entity_browser "tabs" plugin, the tab labels don't
 * initially honor the "widget_context". That's because of the order
 * in which the various plugins are built. The tab labels get created before
 * the widget forms get built, which is where handleWidgetContext() is called.
 * After clicking a couple tabs, the labels would get updated to the label
 * we want, but that's too late. That's why we have to do this little
 * class extension here.
 *
 * @EntityBrowserWidgetSelector(
 *   id = "micronode_block_tabs",
 *   label = @Translation("Tabs (Micronode Block)"),
 *   description = @Translation("Creates horizontal tabs on the top of the entity browser, each tab representing one available widget, treating 'Micronode' and 'Microcontent' as tokens in widget labels.")
 * )
 */
class MicronodeBlockTabs extends Tabs {

  /**
   * {@inheritdoc}
   */
  public function getForm(array &$form = [], FormStateInterface &$form_state = NULL) {
    $element = parent::getForm($form, $form_state);

    // Treat "Micronode" and "Microcontent" like tokens in the tabs labels,
    // replacing those words with the bundle label.
    if ($bundle_label = $form_state->getStorage()['entity_browser']['widget_context']['bundle_label'] ?? NULL) {
      foreach ($element as $key => &$tab) {
        if (!str_starts_with($key, '#')) {
          $tab['#value'] = str_replace(['Micronode', 'Microcontent'], $bundle_label, $tab['#value']);
        }
      }
    }
    return $element;
  }

}
